# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/company.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/company.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from meshtrade.compliance.client.v1 import company_representative_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_company__representative__pb2
from meshtrade.compliance.client.v1 import fund_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_fund__pb2
from meshtrade.compliance.client.v1 import industry_classification_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_industry__classification__pb2
from meshtrade.compliance.client.v1 import natural_person_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_natural__person__pb2
from meshtrade.compliance.client.v1 import trust_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_trust__pb2
from meshtrade.type.v1 import address_pb2 as meshtrade_dot_type_dot_v1_dot_address__pb2
from meshtrade.type.v1 import decimal_pb2 as meshtrade_dot_type_dot_v1_dot_decimal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,meshtrade/compliance/client/v1/company.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x16google/type/date.proto\x1a;meshtrade/compliance/client/v1/company_representative.proto\x1a)meshtrade/compliance/client/v1/fund.proto\x1a<meshtrade/compliance/client/v1/industry_classification.proto\x1a\x33meshtrade/compliance/client/v1/natural_person.proto\x1a*meshtrade/compliance/client/v1/trust.proto\x1a\x1fmeshtrade/type/v1/address.proto\x1a\x1fmeshtrade/type/v1/decimal.proto\"\xc7\t\n\x07\x43ompany\x12\x31\n\x0fregistered_name\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01R\x0eregisteredName\x12\x38\n\x13registration_number\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x18\x64R\x12registrationNumber\x12.\n\x0etax_identifier\x18\x04 \x01(\tB\x07\xbaH\x04r\x02\x18\x32R\rtaxIdentifier\x12\xe3\x01\n\x18\x63ountry_of_incorporation\x18\x05 \x01(\tB\xa8\x01\xbaH\xa4\x01\xba\x01\xa0\x01\n\x1c\x63ountry_code.format.optional\x12Qcountry_of_incorporation must be empty or a valid ISO 3166-1 alpha-2 country code\x1a-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')R\x16\x63ountryOfIncorporation\x12\x45\n\x15\x64\x61te_of_incorporation\x18\x06 \x01(\x0b\x32\x11.google.type.DateR\x13\x64\x61teOfIncorporation\x12I\n\x12registered_address\x18\x07 \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\x11registeredAddress\x12X\n\x1aprincipal_physical_address\x18\x08 \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\x18principalPhysicalAddress\x12\x41\n\x0epostal_address\x18\t \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\rpostalAddress\x12J\n\x13head_office_address\x18\n \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\x11headOfficeAddress\x12n\n\x17\x63ompany_representatives\x18\x0b \x03(\x0b\x32\x35.meshtrade.compliance.client.v1.CompanyRepresentativeR\x16\x63ompanyRepresentatives\x12l\n\x17\x63onnected_legal_persons\x18\x0c \x03(\x0b\x32\x34.meshtrade.compliance.client.v1.ConnectedLegalPersonR\x15\x63onnectedLegalPersons\x12o\n\x17industry_classification\x18\r \x01(\x0b\x32\x36.meshtrade.compliance.client.v1.IndustryClassificationR\x16industryClassification\x12\x39\n\x14listed_exchange_code\x18\x0e \x01(\tB\x07\xbaH\x04r\x02\x18\x14R\x12listedExchangeCode\x12\x34\n\x11listing_reference\x18\x0f \x01(\tB\x07\xbaH\x04r\x02\x18\x14R\x10listingReference\"\x99\x05\n\x14\x43onnectedLegalPerson\x12V\n\x0enatural_person\x18\x01 \x01(\x0b\x32-.meshtrade.compliance.client.v1.NaturalPersonH\x00R\rnaturalPerson\x12\x43\n\x07\x63ompany\x18\x02 \x01(\x0b\x32\'.meshtrade.compliance.client.v1.CompanyH\x00R\x07\x63ompany\x12:\n\x04\x66und\x18\x03 \x01(\x0b\x32$.meshtrade.compliance.client.v1.FundH\x00R\x04\x66und\x12=\n\x05trust\x18\x04 \x01(\x0b\x32%.meshtrade.compliance.client.v1.TrustH\x00R\x05trust\x12s\n\x10\x63onnection_types\x18\x05 \x03(\x0e\x32\x39.meshtrade.compliance.client.v1.LegalPersonConnectionTypeB\r\xbaH\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01R\x0f\x63onnectionTypes\x12M\n\x14ownership_percentage\x18\x06 \x01(\x0b\x32\x1a.meshtrade.type.v1.DecimalR\x13ownershipPercentage\x12T\n\x18voting_rights_percentage\x18\x07 \x01(\x0b\x32\x1a.meshtrade.type.v1.DecimalR\x16votingRightsPercentage\x12?\n\x16\x63onnection_description\x18\x08 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03R\x15\x63onnectionDescriptionB\x0e\n\x0clegal_person*\xe3\x02\n\x19LegalPersonConnectionType\x12,\n(LEGAL_PERSON_CONNECTION_TYPE_UNSPECIFIED\x10\x00\x12,\n(LEGAL_PERSON_CONNECTION_TYPE_SHAREHOLDER\x10\x01\x12/\n+LEGAL_PERSON_CONNECTION_TYPE_PARENT_COMPANY\x10\x02\x12\x33\n/LEGAL_PERSON_CONNECTION_TYPE_CORPORATE_DIRECTOR\x10\x03\x12&\n\"LEGAL_PERSON_CONNECTION_TYPE_TRUST\x10\x04\x12\x30\n,LEGAL_PERSON_CONNECTION_TYPE_GENERAL_PARTNER\x10\x05\x12*\n&LEGAL_PERSON_CONNECTION_TYPE_GUARANTOR\x10\x06\x42\x63\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.company_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_COMPANY'].fields_by_name['registered_name']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['registered_name']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_COMPANY'].fields_by_name['registration_number']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['registration_number']._serialized_options = b'\272H\004r\002\030d'
  _globals['_COMPANY'].fields_by_name['tax_identifier']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['tax_identifier']._serialized_options = b'\272H\004r\002\0302'
  _globals['_COMPANY'].fields_by_name['country_of_incorporation']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['country_of_incorporation']._serialized_options = b'\272H\244\001\272\001\240\001\n\034country_code.format.optional\022Qcountry_of_incorporation must be empty or a valid ISO 3166-1 alpha-2 country code\032-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')'
  _globals['_COMPANY'].fields_by_name['listed_exchange_code']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['listed_exchange_code']._serialized_options = b'\272H\004r\002\030\024'
  _globals['_COMPANY'].fields_by_name['listing_reference']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['listing_reference']._serialized_options = b'\272H\004r\002\030\024'
  _globals['_CONNECTEDLEGALPERSON'].fields_by_name['connection_types']._loaded_options = None
  _globals['_CONNECTEDLEGALPERSON'].fields_by_name['connection_types']._serialized_options = b'\272H\n\222\001\007\"\005\202\001\002\020\001'
  _globals['_CONNECTEDLEGALPERSON'].fields_by_name['connection_description']._loaded_options = None
  _globals['_CONNECTEDLEGALPERSON'].fields_by_name['connection_description']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_LEGALPERSONCONNECTIONTYPE']._serialized_start=2357
  _globals['_LEGALPERSONCONNECTIONTYPE']._serialized_end=2712
  _globals['_COMPANY']._serialized_start=463
  _globals['_COMPANY']._serialized_end=1686
  _globals['_CONNECTEDLEGALPERSON']._serialized_start=1689
  _globals['_CONNECTEDLEGALPERSON']._serialized_end=2354
# @@protoc_insertion_point(module_scope)
