from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class NaturalPersonConnectionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NATURAL_PERSON_CONNECTION_TYPE_UNSPECIFIED: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_ULTIMATE_BENEFICIAL_OWNER: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_SHAREHOLDER: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_DIRECTOR: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_SENIOR_MANAGEMENT: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_AUTHORIZED_SIGNATORY: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_FOUNDER: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_SPOUSE: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_DOMESTIC_PARTNER: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_PARENT: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_CHILD: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_SIBLING: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_BUSINESS_PARTNER: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_CLOSE_ASSOCIATE: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_GUARANTOR: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_BENEFICIARY_OF_TRUST: _ClassVar[NaturalPersonConnectionType]
NATURAL_PERSON_CONNECTION_TYPE_UNSPECIFIED: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_ULTIMATE_BENEFICIAL_OWNER: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_SHAREHOLDER: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_DIRECTOR: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_SENIOR_MANAGEMENT: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_AUTHORIZED_SIGNATORY: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_FOUNDER: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_SPOUSE: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_DOMESTIC_PARTNER: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_PARENT: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_CHILD: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_SIBLING: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_BUSINESS_PARTNER: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_CLOSE_ASSOCIATE: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_GUARANTOR: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_BENEFICIARY_OF_TRUST: NaturalPersonConnectionType
