# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.market_data.price.v1 import price_pb2 as meshtrade_dot_market__data_dot_price_dot_v1_dot_price__pb2
from meshtrade.market_data.price.v1 import service_pb2 as meshtrade_dot_market__data_dot_price_dot_v1_dot_service__pb2


class PriceServiceStub(object):
    """
    PriceService provides market data pricing information.

    This service enables retrieval of current market prices for token pairs,
    supporting trading decisions and portfolio valuation.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCurrentPriceByTokenPair = channel.unary_unary(
                '/meshtrade.market_data.price.v1.PriceService/GetCurrentPriceByTokenPair',
                request_serializer=meshtrade_dot_market__data_dot_price_dot_v1_dot_service__pb2.GetCurrentPriceByTokenPairRequest.SerializeToString,
                response_deserializer=meshtrade_dot_market__data_dot_price_dot_v1_dot_price__pb2.Price.FromString,
                _registered_method=True)


class PriceServiceServicer(object):
    """
    PriceService provides market data pricing information.

    This service enables retrieval of current market prices for token pairs,
    supporting trading decisions and portfolio valuation.
    """

    def GetCurrentPriceByTokenPair(self, request, context):
        """
        Retrieves the current price for a specified token pair.

        Returns the mid-market price for the base token denominated in the quote token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PriceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCurrentPriceByTokenPair': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurrentPriceByTokenPair,
                    request_deserializer=meshtrade_dot_market__data_dot_price_dot_v1_dot_service__pb2.GetCurrentPriceByTokenPairRequest.FromString,
                    response_serializer=meshtrade_dot_market__data_dot_price_dot_v1_dot_price__pb2.Price.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.market_data.price.v1.PriceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.market_data.price.v1.PriceService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PriceService(object):
    """
    PriceService provides market data pricing information.

    This service enables retrieval of current market prices for token pairs,
    supporting trading decisions and portfolio valuation.
    """

    @staticmethod
    def GetCurrentPriceByTokenPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.market_data.price.v1.PriceService/GetCurrentPriceByTokenPair',
            meshtrade_dot_market__data_dot_price_dot_v1_dot_service__pb2.GetCurrentPriceByTokenPairRequest.SerializeToString,
            meshtrade_dot_market__data_dot_price_dot_v1_dot_price__pb2.Price.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
