# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/trading/market_order/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/trading/market_order/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.option.method_options.v1 import method_options_pb2 as meshtrade_dot_option_dot_method__options_dot_v1_dot_method__options__pb2
from meshtrade.trading.market_order.v1 import market_order_pb2 as meshtrade_dot_trading_dot_market__order_dot_v1_dot_market__order__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/meshtrade/trading/market_order/v1/service.proto\x12!meshtrade.trading.market_order.v1\x1a\x37meshtrade/option/method_options/v1/method_options.proto\x1a\x34meshtrade/trading/market_order/v1/market_order.proto\"/\n\x15GetMarketOrderRequest\x12\x16\n\x06number\x18\x01 \x01(\tR\x06number2\xa5\x01\n\x12MarketOrderService\x12\x8e\x01\n\x0eGetMarketOrder\x12\x38.meshtrade.trading.market_order.v1.GetMarketOrderRequest\x1a..meshtrade.trading.market_order.v1.MarketOrder\"\x12\xb2\xb5\x18\x0e\x08\x01\x10\x02\x1a\x08\xc0\x96\xb1\x02\xc1\x96\xb1\x02\x42o\n(co.meshtrade.api.trading.market_order.v1ZCgithub.com/meshtrade/api/go/trading/market_order/v1;market_order_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.trading.market_order.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(co.meshtrade.api.trading.market_order.v1ZCgithub.com/meshtrade/api/go/trading/market_order/v1;market_order_v1'
  _globals['_MARKETORDERSERVICE'].methods_by_name['GetMarketOrder']._loaded_options = None
  _globals['_MARKETORDERSERVICE'].methods_by_name['GetMarketOrder']._serialized_options = b'\262\265\030\016\010\001\020\002\032\010\300\226\261\002\301\226\261\002'
  _globals['_GETMARKETORDERREQUEST']._serialized_start=197
  _globals['_GETMARKETORDERREQUEST']._serialized_end=244
  _globals['_MARKETORDERSERVICE']._serialized_start=247
  _globals['_MARKETORDERSERVICE']._serialized_end=412
# @@protoc_insertion_point(module_scope)
